/****************************************************************************
** Meta object code from reading C++ file 'qtriggerbody_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3dphysics/src/quick3dphysics/qtriggerbody_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtriggerbody_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12QTriggerBodyE_t {};
} // unnamed namespace

template <> constexpr inline auto QTriggerBody::qt_create_metaobjectdata<qt_meta_tag_ZN12QTriggerBodyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTriggerBody",
        "QML.Element",
        "TriggerBody",
        "bodyEntered",
        "",
        "QAbstractPhysicsNode*",
        "body",
        "bodyExited",
        "collisionCountChanged",
        "collisionCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bodyEntered'
        QtMocHelpers::SignalData<void(QAbstractPhysicsNode *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'bodyExited'
        QtMocHelpers::SignalData<void(QAbstractPhysicsNode *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'collisionCountChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'collisionCount'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QTriggerBody, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QTriggerBody::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractPhysicsNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QTriggerBodyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QTriggerBodyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12QTriggerBodyE_t>.metaTypes,
    nullptr
} };

void QTriggerBody::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTriggerBody *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bodyEntered((*reinterpret_cast<std::add_pointer_t<QAbstractPhysicsNode*>>(_a[1]))); break;
        case 1: _t->bodyExited((*reinterpret_cast<std::add_pointer_t<QAbstractPhysicsNode*>>(_a[1]))); break;
        case 2: _t->collisionCountChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractPhysicsNode* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractPhysicsNode* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QTriggerBody::*)(QAbstractPhysicsNode * )>(_a, &QTriggerBody::bodyEntered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTriggerBody::*)(QAbstractPhysicsNode * )>(_a, &QTriggerBody::bodyExited, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTriggerBody::*)()>(_a, &QTriggerBody::collisionCountChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->collisionCount(); break;
        default: break;
        }
    }
}

const QMetaObject *QTriggerBody::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTriggerBody::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QTriggerBodyE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractPhysicsNode::qt_metacast(_clname);
}

int QTriggerBody::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractPhysicsNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QTriggerBody::bodyEntered(QAbstractPhysicsNode * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QTriggerBody::bodyExited(QAbstractPhysicsNode * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QTriggerBody::collisionCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
