//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
//  * Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
//  * Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//  * Neither the name of NVIDIA CORPORATION nor the names of its
//    contributors may be used to endorse or promote products derived
//    from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ''AS IS'' AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
// OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Copyright (c) 2008-2021 NVIDIA Corporation. All rights reserved.
// Copyright (c) 2004-2008 AGEIA Technologies, Inc. All rights reserved.
// Copyright (c) 2001-2004 NovodeX AG. All rights reserved.  


#include "BpSAPTasks.h"
#include "BpBroadPhaseSap.h"
#include "PsTime.h"

namespace physx
{

namespace Bp
{

///////////////////////////////////////////////////////////////////////////////


//	#define DUMP_TOTAL_SAP_TIME
// 256 convex stacks: from ~13000 down to ~2000
// pot pourri box: from ~4000 to ~700
// boxes: ~3400 to ~4000

#ifdef DUMP_TOTAL_SAP_TIME
	static PxU64 gStartTime = shdfnd::Time::getCurrentCounterValue();
#endif

void SapUpdateWorkTask::runInternal()
{
	mSAP->update();
}

void SapPostUpdateWorkTask::runInternal()
{
	mSAP->postUpdate();
#ifdef DUMP_TOTAL_SAP_TIME
	PxU64 endTime = shdfnd::Time::getCurrentCounterValue();
	printf("SAP Time: %" PX_PRIu64 "\n", endTime - gStartTime);
#endif
}

} //namespace Bp

} //namespace physx
